;; Generated package description from activities.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "activities" "0.80.20251118.85" "Save/restore sets of windows, tabs/frames, and their buffers" '((emacs "28.2") (persist "0.6")) :commit "5025962126d140a7e26d36c3a2750bf4ff0bfd45" :authors '(("Adam Porter" . "adam@alphapapa.net")) :maintainer '("Adam Porter" . "adam@alphapapa.net") :keywords '("convenience") :url "https://github.com/alphapapa/activities.el")
